@@ -9,15 +9,15 @@ Copyright (c) 2009-2012 Exa Networks. All rights reserved.
 
 import unittest
 
-from exabgp.message.open         import Open,Capabilities,new_Open
-from exabgp.message.notification import Notification
-from exabgp.message.keepalive    import KeepAlive,new_KeepAlive
-from exabgp.message.update       import Update,Attributes
+from exabgp.bgp.message.open import Open,Capabilities,new_Open
+from exabgp.bgp.message.notification import Notification
+from exabgp.bgp.message.keepalive import KeepAlive,new_KeepAlive
+from exabgp.bgp.message.update import Update,Attributes
 
-from exabgp.rib.table            import Table
-from exabgp.rib.delta            import Delta
-from exabgp.network.protocol     import Protocol
-from exabgp.structure.neighbor   import Neighbor
+from exabgp.rib.table import Table
+from exabgp.rib.delta import Delta
+from exabgp.bgp.protocol import Protocol
+from exabgp.bgp.neighbor import Neighbor
 
 from StringIO import StringIO
 
@@ -45,8 +45,8 @@ class TestProtocol (unittest.TestCase):
 		self.neighbor = Neighbor()
 		self.neighbor.local_as = ASN(65000)
 		self.neighbor.peer_as = ASN(65000)
-		self.neighbor.peer_address = to_IP('1.2.3.4')
-		self.neighbor.local_address = to_IP('5.6.7.8')
+		self.neighbor.peer_address = InetIP('1.2.3.4')
+		self.neighbor.local_address = InetIP('5.6.7.8')
 
 	def test_4_selfparse_update_announce (self):
 		o = Open(4,65000,'1.2.3.4',Capabilities().default(),30).message()
