@@ -9,8 +9,8 @@ Copyright (c) 2009-2012 Exa Networks. All rights reserved.
 
 import unittest
 
-from exabgp.structure.address import AFI,SAFI
-from exabgp.structure.ip import *
+from exabgp.protocol.family import AFI,SAFI
+from exabgp.protocol.ip.inet import *
 
 class TestData (unittest.TestCase):
 	def test_1_nlri_1 (self):
@@ -21,23 +21,23 @@ class TestData (unittest.TestCase):
 		self.assertEqual(''.join([chr(c) for c in [20,1,2,3]]),to_NLRI('1.2.3.4','20').pack())
 
 	def test_2_ip_2 (self):
-		self.assertEqual(str(to_IP('::ffff:192.168.1.26')),'::ffff:192.168.1.26/128')
-		self.assertEqual(str(to_IP('::ffff:192.168.1.26').ip),'::ffff:192.168.1.26')
+		self.assertEqual(str(InetIP('::ffff:192.168.1.26')),'::ffff:192.168.1.26/128')
+		self.assertEqual(str(InetIP('::ffff:192.168.1.26').ip),'::ffff:192.168.1.26')
 
 	def test_3_ipv6_1 (self):
-		default = to_IP('::')
+		default = InetIP('::')
 		self.assertEqual(str(default),'::/128')
 		self.assertEqual(default.ip,'::')
 		self.assertEqual(default.packedip(),'\0'*16)
 
 	def test_3_ipv6_2 (self):
-		default = to_IP('1234:5678::')
+		default = InetIP('1234:5678::')
 		self.assertEqual(str(default),'1234:5678::/128')
 		self.assertEqual(default.ip,'1234:5678::')
 		self.assertEqual(default.packedip(),'\x12\x34\x56\x78'+'\0'*12)
 
 	def test_3_ipv6_3 (self):
-		default = to_IP('1234:5678::1')
+		default = InetIP('1234:5678::1')
 		self.assertEqual(str(default),'1234:5678::1/128')
 		self.assertEqual(default.ip,'1234:5678::1')
 		self.assertEqual(default.packedip(),'\x12\x34\x56\x78'+'\0'*11 + '\x01')
@@ -48,8 +48,7 @@ class TestData (unittest.TestCase):
 		bnt = chr(24) + chr (192) + chr(0) + chr(2)
 
 		pfx = Prefix(AFI.ipv4,ip,24)
-		afi = AFIPrefix(AFI.ipv4,net,24)
-		bgp = BGPPrefix(AFI.ipv4,bnt)
+		bgp = BGPNLRI(AFI.ipv4,bnt)
 
 		self.assertEqual(str(pfx),"%s/24" % ip)
 		self.assertEqual(str(afi),"%s/24" % ip)
