@@ -9,8 +9,8 @@ Copyright (c) 2009-2012 Exa Networks. All rights reserved.
 
 import unittest
 
-from exabgp.message.update.update import *
-from exabgp.message.update.attribute.communities import to_Community, Community, Communities
+from exabgp.bgp.message.update.update import *
+from exabgp.bgp.message.update.attribute.communities import to_Community, Community, Communities
 
 class TestData (unittest.TestCase):
 	def test_2_prefix (self):
@@ -51,7 +51,7 @@ class TestData (unittest.TestCase):
 		self.assertEqual(str(update.nlri[0]),'1234:5678::/32')
 
 	def test_1_ipv6_2 (self):
-		route = to_Route('1234:5678::',64)
+		route = RouteIP('1234:5678::',64)
 		route.next_hop = '8765:4321::1'
 		announced = route.announce(1,1)
 		message = announced[19:]
